.. _changelog:

Release notes
#############

.. figure:: /images/pike-release.jpg
    :figwidth: 30%
    :alt: pike fish being released to water
    :align: right

    Releasing a pike.

pikepdf releases use the `semantic versioning <https://semver.org>`__
policy.

The pikepdf API (as provided by ``import pikepdf``) is stable and
is in production use. Note that the C++ extension module
``pikepdf._core`` is a private interface within pikepdf that applications
should not access directly, along with any modules with a prefixed underscore.

.. toctree::
  :maxdepth: 1
  :glob:
  :reversed:

  version*
